Module: ElasticGraph

Defined in:
lib/elastic_graph/indexer_autoscaler_lambda/details_logger.rb,
lib/elastic_graph/indexer_autoscaler_lambda.rb,
lib/elastic_graph/indexer_autoscaler_lambda/lambda_function.rb,
lib/elastic_graph/indexer_autoscaler_lambda/concurrency_scaler.rb

Overview

Copyright 2024 - 2026 Block, Inc.

Use of this source code is governed by an MIT-style license that can be found in the LICENSE file or at opensource.org/licenses/MIT.

frozen_string_literal: true

Defined Under Namespace

Classes: IndexerAutoscalerLambda